@@ -3,7 +3,7 @@
 // The University of Illinois/NCSA
 // Open Source License (NCSA)
 //
-// Copyright (c) 2014-2020, Advanced Micro Devices, Inc. All rights reserved.
+// Copyright (c) 2014-2025, Advanced Micro Devices, Inc. All rights reserved.
 //
 // Developed by:
 //
@@ -74,8 +74,9 @@ class GpuAgentInt : public core::Agent {
  public:
   // @brief Constructor
    GpuAgentInt(uint32_t node_id)
-       : core::Agent(core::DriverType::KFD, node_id,
-                     core::Agent::DeviceType::kAmdGpuDevice) {}
+       : core::Agent(core::Runtime::runtime_singleton_->AgentDriver(
+                         core::DriverType::KFD),
+                     node_id, core::Agent::DeviceType::kAmdGpuDevice) {}
 
    // @brief Ensure blits are ready (performance hint).
    virtual void PreloadBlits() {}
@@ -86,6 +87,8 @@ class GpuAgentInt : public core::Agent {
    // @retval HSA_STATUS_SUCCESS if initialization is successful.
    virtual hsa_status_t PostToolsInit() = 0;
 
+   virtual void ReleaseResources() = 0;
+
    // @brief Invoke the user provided callback for each region accessible by
    // this agent.
    //
@@ -148,7 +151,7 @@ class GpuAgentInt : public core::Agent {
    virtual uint64_t TranslateTime(uint64_t tick) = 0;
 
    // @brief Invalidate caches on the agent which may hold code object data.
-   virtual void InvalidateCodeCaches() = 0;
+   virtual void InvalidateCodeCaches(void *ptr, size_t size) = 0;
 
    // @brief Sets the coherency type of this agent.
    //
@@ -168,10 +171,7 @@ class GpuAgentInt : public core::Agent {
    virtual void RegisterRecSdmaEngIdMaskPeer(core::Agent &gang_peer,
                                              uint32_t rec_sdma_eng_id_mask) = 0;
 
-   // @brief Query if agent represent Kaveri GPU.
-   //
-   // @retval true if agent is Kaveri GPU.
-   virtual bool is_kv_device() const = 0;
+   virtual void SetRecSdmaEngOverride(bool flag) = 0;
 
    // @brief Query the agent HSA profile.
    //
@@ -236,6 +236,9 @@ class GpuAgent : public GpuAgentInt {
   // @brief GPU agent destructor.
   ~GpuAgent();
 
+  // @brief Release allocated resources and disables agent
+  void ReleaseResources() override;
+
   // @brief Ensure blits are ready (performance hint).
   void PreloadBlits() override;
 
@@ -275,6 +278,10 @@ class GpuAgent : public GpuAgentInt {
                                                       void* data),
                              void* data) const override;
 
+  hsa_status_t IterateSupportedIsas(
+                    hsa_status_t (*callback)(hsa_isa_t isa, void* data),
+                                                  void* data) const override;
+
   // @brief Override from core::Agent.
   hsa_status_t IterateCache(hsa_status_t (*callback)(hsa_cache_t cache, void* data),
                             void* value) const override;
@@ -299,6 +306,10 @@ class GpuAgent : public GpuAgentInt {
   hsa_status_t DmaCopyStatus(core::Agent& dst_agent, core::Agent& src_agent,
                              uint32_t *engine_ids_mask) override;
 
+  // @brief Override from core::Agent.
+  hsa_status_t DmaPreferredEngine(core::Agent& dst_agent, core::Agent& src_agent,
+                                  uint32_t* recommended_ids_mask) override;
+
   // @brief Override from core::Agent.
   hsa_status_t DmaCopyRect(const hsa_pitched_ptr_t* dst, const hsa_dim3_t* dst_offset,
                            const hsa_pitched_ptr_t* src, const hsa_dim3_t* src_offset,
@@ -312,10 +323,9 @@ class GpuAgent : public GpuAgentInt {
   hsa_status_t GetInfo(hsa_agent_info_t attribute, void* value) const override;
 
   // @brief Override from core::Agent.
-  hsa_status_t QueueCreate(size_t size, hsa_queue_type32_t queue_type,
+  hsa_status_t QueueCreate(size_t size, hsa_queue_type32_t queue_type, uint64_t flags,
                            core::HsaEventCallback event_callback, void* data,
-                           uint32_t private_segment_size,
-                           uint32_t group_segment_size,
+                           uint32_t private_segment_size, uint32_t group_segment_size,
                            core::Queue** queue) override;
 
   // @brief Decrement GWS ref count.
@@ -338,7 +348,7 @@ class GpuAgent : public GpuAgentInt {
   uint64_t TranslateTime(uint64_t tick) override;
 
   // @brief Override from AMD::GpuAgentInt.
-  void InvalidateCodeCaches() override;
+  void InvalidateCodeCaches(void* ptr, size_t size) override;
 
   // @brief Override from AMD::GpuAgentInt.
   bool current_coherency_type(hsa_amd_coherency_type_t type) override;
@@ -366,6 +376,9 @@ class GpuAgent : public GpuAgentInt {
     return properties_;
   }
 
+  // @brief set rec_sdma_eng_override_
+  __forceinline void SetRecSdmaEngOverride(bool flag) override { rec_sdma_eng_override_ = flag; }
+
   // @brief Returns number of data caches.
   __forceinline size_t num_cache() const { return cache_props_.size(); }
 
@@ -381,11 +394,8 @@ class GpuAgent : public GpuAgentInt {
     return regions_;
   }
 
-  // @brief Override from core::Agent.
-  const core::Isa* isa() const override { return isa_; }
-
-  // @brief Override from AMD::GpuAgentInt.
-  __forceinline bool is_kv_device() const override { return is_kv_device_; }
+  const std::vector<const core::Isa *>& supported_isas() const override {
+                                                      return supported_isas_;}
 
   // @brief Override from AMD::GpuAgentInt.
   __forceinline hsa_profile_t profile() const override { return profile_; }
@@ -417,8 +427,21 @@ class GpuAgent : public GpuAgentInt {
     if (t0_.GPUClockCounter == t1_.GPUClockCounter) SyncClocks();
   }
 
-  // @brief Override from AMD::GpuAgentInt.
+  /// @brief Override from AMD::GpuAgentInt.
   __forceinline bool is_xgmi_cpu_gpu() const { return xgmi_cpu_gpu_; }
+  /// @brief Is large BAR support enabled for this GPU.
+  __forceinline bool LargeBarEnabled() const { return large_bar_enabled_; }
+
+  /// @brief Force a WC flush on PCIe devices by doing a write and then read-back
+  __forceinline void PcieWcFlush(void *ptr, size_t size) const {
+    if (!xgmi_cpu_gpu_) {
+      _mm_sfence();
+      *((uint8_t*)ptr + size - 1) = *((uint8_t*)ptr + size - 1);
+      _mm_mfence();
+      auto readback = *(reinterpret_cast<volatile uint8_t*>(ptr) + size - 1);
+      UNUSED(readback);
+    }
+  }
 
   const size_t MAX_SCRATCH_APERTURE_PER_XCC = (1ULL << 32);
   size_t MaxScratchDevice() const { return properties_.NumXcc * MAX_SCRATCH_APERTURE_PER_XCC; }
@@ -430,10 +453,15 @@ class GpuAgent : public GpuAgentInt {
 
   // @brief Returns true if scratch reclaim is enabled
   __forceinline bool AsyncScratchReclaimEnabled() const override {
-    // TODO: Need to update min CP FW ucode version once it is released
+    const uint32_t GFX94X_MIN_CP_FW_VERSION_REQUIRED = 177;
+    const uint32_t GFX95X_MIN_CP_FW_VERSION_REQUIRED = 24;
+
     return (core::Runtime::runtime_singleton_->flag().enable_scratch_async_reclaim() &&
-            isa()->GetMajorVersion() == 9 && isa()->GetMinorVersion() == 4 &&
-            properties_.EngineId.ui32.uCode > 999);
+	    supported_isas()[0]->GetMajorVersion() == 9 &&
+	    ((supported_isas()[0]->GetMinorVersion() == 4 &&
+	      properties_.EngineId.ui32.uCode >= GFX94X_MIN_CP_FW_VERSION_REQUIRED) ||
+	     (supported_isas()[0]->GetMinorVersion() == 5 &&
+	      properties_.EngineId.ui32.uCode >= GFX95X_MIN_CP_FW_VERSION_REQUIRED)));
   };
 
   hsa_status_t SetAsyncScratchThresholds(size_t use_once_limit) override;
@@ -458,6 +486,18 @@ class GpuAgent : public GpuAgentInt {
 
   const std::function<void(void*)>& finegrain_deallocator() const { return finegrain_deallocator_; }
 
+  /// @brief Allocate coarse grain device memory on this GPU agent.
+  const std::function<void*(size_t size, core::MemoryRegion::AllocateFlags flags)>&
+  coarsegrain_allocator() const {
+    return coarsegrain_allocator_;
+  }
+
+  /// @brief Deallocate memory allocated from the coarsegrain_allocator
+  /// on this GPU agent.
+  const std::function<void(void*)>& coarsegrain_deallocator() const {
+    return coarsegrain_deallocator_;
+  }
+
  protected:
   // Sizes are in packets.
   const uint32_t minAqlSize_ = 0x40;     // 4KB min
@@ -501,24 +541,20 @@ class GpuAgent : public GpuAgentInt {
 
   // @brief Binds the second-level trap handler to this node.
   void BindTrapHandler();
-  hsa_status_t UpdateTrapHandlerWithPCS(void* pcs_hosttrap_buffers, void* stochastic_hosttrap_buffers);
 
   // @brief Override from core::Agent.
   hsa_status_t EnableDmaProfiling(bool enable) override;
 
   hsa_status_t PcSamplingIterateConfig(hsa_ven_amd_pcs_iterate_configuration_callback_t cb,
-                                       void* cb_data);
-  hsa_status_t PcSamplingCreate(pcs::PcsRuntime::PcSamplingSession& session);
+                                       void* cb_data) override;
+  hsa_status_t PcSamplingCreate(pcs::PcsRuntime::PcSamplingSession& session) override;
   hsa_status_t PcSamplingCreateFromId(HsaPcSamplingTraceId pcsId,
-                                      pcs::PcsRuntime::PcSamplingSession& session);
-  hsa_status_t PcSamplingDestroy(pcs::PcsRuntime::PcSamplingSession& session);
-  hsa_status_t PcSamplingStart(pcs::PcsRuntime::PcSamplingSession& session);
-  hsa_status_t PcSamplingStop(pcs::PcsRuntime::PcSamplingSession& session);
-  hsa_status_t PcSamplingFlush(pcs::PcsRuntime::PcSamplingSession& session);
-  hsa_status_t PcSamplingFlushHostTrapDeviceBuffers(pcs::PcsRuntime::PcSamplingSession& session);
-
-  static void PcSamplingThreadRun(void* agent);
-  void PcSamplingThread();
+                            pcs::PcsRuntime::PcSamplingSession& session) override;
+  hsa_status_t PcSamplingDestroy(pcs::PcsRuntime::PcSamplingSession& session) override;
+  hsa_status_t PcSamplingStart(pcs::PcsRuntime::PcSamplingSession& session) override;
+  hsa_status_t PcSamplingStop(pcs::PcsRuntime::PcSamplingSession& session) override;
+  hsa_status_t PcSamplingFlush(pcs::PcsRuntime::PcSamplingSession& session) override;
+  hsa_status_t PcSamplingFlushDeviceBuffers(pcs::PcsRuntime::PcSamplingSession& session);
 
   // @brief Node properties.
   const HsaNodeProperties properties_;
@@ -605,15 +641,13 @@ class GpuAgent : public GpuAgentInt {
   // @brief HSA profile.
   hsa_profile_t profile_;
 
-  bool is_kv_device_;
-
   void* trap_code_buf_;
 
   size_t trap_code_buf_size_;
 
   // @brief Mappings from doorbell index to queue, for trap handler.
   // Correlates with output of s_sendmsg(MSG_GET_DOORBELL) for queue identification.
-  amd_queue_t** doorbell_queue_map_;
+  amd_queue_v2_t** doorbell_queue_map_;
 
   // @brief The GPU memory bus width in bit.
   uint32_t memory_bus_width_;
@@ -710,20 +744,23 @@ class GpuAgent : public GpuAgentInt {
   uint32_t sdma_blit_used_mask_;
 
   // Scratch limit thresholds when async scratch is enabled.
-  size_t scratch_limit_async_threshold_;
+  uint64_t scratch_limit_async_threshold_;
 
   ScratchCache scratch_cache_;
 
-  // System memory allocator in the nearest NUMA node.
+  /// @brief System memory allocator in the nearest NUMA node.
   std::function<void*(size_t size, size_t align, core::MemoryRegion::AllocateFlags flags)>
       system_allocator_;
-
+  /// @brief System memory deallocator in the nearest NUMA node.
   std::function<void(void*)> system_deallocator_;
-
-  // Fine grain allocator on this device
+  /// @brief Fine-grain allocator on this GPU.
   std::function<void*(size_t size, core::MemoryRegion::AllocateFlags flags)> finegrain_allocator_;
-
+  /// @brief Fine-grain deallocator on this GPU.
   std::function<void(void*)> finegrain_deallocator_;
+  /// @brief Coarse-grain allocator on this GPU.
+  std::function<void*(size_t size, core::MemoryRegion::AllocateFlags flags)> coarsegrain_allocator_;
+  /// @brief Coarse-grain deallocator on this GPU.
+  std::function<void(void*)> coarsegrain_deallocator_;
 
   void* trap_handler_tma_region_;
 
@@ -742,13 +779,13 @@ class GpuAgent : public GpuAgentInt {
     uint8_t reserved1[16];
     /* pc_sample_t buffer0[buf_size]; */
     /* pc_sample_t buffer1[buf_size]; */
-  } pcs_hosttrap_sampling_data_t;
+  } pcs_sampling_data_t;
 
   typedef struct {
-    /* Hosttrap data - stored on device so that trap_handler code can access efficiently */
-    pcs_hosttrap_sampling_data_t* device_data;
+    /* Sampling data - stored on device for trap handler access */
+    pcs_sampling_data_t* device_data;
 
-    /* Hosttrap host buffer - stored on host */
+    /* Sampling host buffer - stored on host */
     uint8_t* host_buffer;
     size_t host_buffer_size;
     uint8_t* host_buffer_wrap_pos;
@@ -767,11 +804,16 @@ class GpuAgent : public GpuAgentInt {
 
     os::Thread thread;
     pcs::PcsRuntime::PcSamplingSession* session;
-  } pcs_hosttrap_t;
-
-  pcs_hosttrap_t pcs_hosttrap_data_;
+  } pcs_data_t;
   /* PC Sampling fields - end */
 
+  hsa_status_t UpdateTrapHandlerWithPCS(pcs_sampling_data_t* pcs_hosttrap_buffers,
+                                        pcs_sampling_data_t* pcs_stochastic_buffers);
+
+  // @brief Thread function to process PC sampling data collected via host-trap
+  // or Stochastic sampling.
+  void PcSamplingThread(pcs_data_t& pcs_data, const char* thread_name);
+
   // @brief device handle
   amdgpu_device_handle ldrm_dev_;
 
@@ -785,9 +827,18 @@ class GpuAgent : public GpuAgentInt {
   std::map<uint64_t, uint32_t> rec_sdma_eng_id_peers_info_;
 
   bool uses_rec_sdma_eng_id_mask_;
+  bool rec_sdma_eng_override_;
 
-  // @bried XGMI CPU<->GPU
+  // structure for host trap sampling
+  pcs_data_t pcs_hosttrap_data_;
+
+  // structure for stochastic sampling
+  pcs_data_t pcs_stochastic_data_;
+
+  /// @brief XGMI CPU<->GPU
   bool xgmi_cpu_gpu_;
+  /// @brief Is PCIe large BAR enabled.
+  bool large_bar_enabled_;
 };
 
 }  // namespace amd
