@@ -427,6 +427,7 @@ hsa_status_t hsa_system_get_major_extension_table(uint16_t extension, uint16_t v
     ext_table.hsa_ext_image_get_capability_with_layout = hsa_ext_image_get_capability_with_layout;
     ext_table.hsa_ext_image_data_get_info_with_layout = hsa_ext_image_data_get_info_with_layout;
     ext_table.hsa_ext_image_create_with_layout = hsa_ext_image_create_with_layout;
+    ext_table.hsa_ext_sampler_create_v2 = hsa_ext_sampler_create_v2;
 
     memcpy(table, &ext_table, Min(sizeof(ext_table), table_length));
 
@@ -534,6 +535,15 @@ hsa_status_t hsa_system_get_major_extension_table(uint16_t extension, uint16_t v
     ext_table.hsa_ven_amd_aqlprofile_iterate_data =
       (decltype(::hsa_ven_amd_aqlprofile_iterate_data)*)
         os::GetExportAddress(lib, "hsa_ven_amd_aqlprofile_iterate_data");
+    ext_table.hsa_ven_amd_aqlprofile_iterate_event_ids =
+      (decltype(::hsa_ven_amd_aqlprofile_iterate_event_ids)*)
+        os::GetExportAddress(lib, "hsa_ven_amd_aqlprofile_iterate_event_ids");
+    ext_table.hsa_ven_amd_aqlprofile_iterate_event_coord =
+      (decltype(::hsa_ven_amd_aqlprofile_iterate_event_coord)*)
+        os::GetExportAddress(lib, "hsa_ven_amd_aqlprofile_iterate_event_coord");
+    ext_table.hsa_ven_amd_aqlprofile_att_marker =
+      (decltype(::hsa_ven_amd_aqlprofile_att_marker)*)
+        os::GetExportAddress(lib, "hsa_ven_amd_aqlprofile_att_marker");
 
     bool version_incompatible = true;
     uint32_t version_curr = 0;
@@ -732,8 +742,13 @@ hsa_status_t hsa_queue_create(
 
   if (callback == nullptr) callback = core::Queue::DefaultErrorHandler;
 
+  uint64_t queue_create_flags = 0;
+
+  if (core::Runtime::runtime_singleton_->flag().dev_mem_queue_buf())
+    queue_create_flags = HSA_AMD_QUEUE_CREATE_DEVICE_MEM_RING_BUF;
+
   core::Queue* cmd_queue = nullptr;
-  status = agent->QueueCreate(size, type, callback, data, private_segment_size,
+  status = agent->QueueCreate(size, type, queue_create_flags, callback, data, private_segment_size,
                               group_segment_size, &cmd_queue);
   if (status != HSA_STATUS_SUCCESS) return status;
 
@@ -764,7 +779,13 @@ hsa_status_t hsa_soft_queue_create(hsa_region_t region, uint32_t size,
   const core::Signal* signal = core::Signal::Convert(doorbell_signal);
   IS_VALID(signal);
 
-  core::HostQueue* host_queue = new core::HostQueue(region, size, type, features, doorbell_signal);
+  void* shared_queue = nullptr;
+  hsa_status_t err = HSA::hsa_memory_allocate(region, sizeof(core::SharedQueue), &shared_queue);
+  if (err != HSA_STATUS_SUCCESS) return err;
+  assert(shared_queue && "Queue struct is NULL when creating host queue.");
+
+  core::HostQueue* host_queue = new core::HostQueue(static_cast<core::SharedQueue*>(shared_queue),
+                                                    region, size, type, features, doorbell_signal);
 
   *queue = core::Queue::Convert(host_queue);
 
@@ -1573,12 +1594,7 @@ hsa_status_t hsa_agent_iterate_isas(
   const core::Agent *agent_object = core::Agent::Convert(agent);
   IS_VALID(agent_object);
 
-  const Isa *isa_object = agent_object->isa();
-  if (!isa_object) {
-    return HSA_STATUS_SUCCESS;
-  }
-
-  return callback(Isa::Handle(isa_object), data);
+  return agent_object->IterateSupportedIsas(callback, data);
   CATCH;
 }
 
@@ -1708,7 +1724,7 @@ hsa_status_t hsa_isa_compatible(
   const Isa *agent_isa_object = Isa::Object(agent_isa);
   IS_VALID(agent_isa_object);
 
-  *result = Isa::IsCompatible(*code_object_isa_object, *agent_isa_object);
+  *result = Isa::IsCompatible(*code_object_isa_object, *agent_isa_object, 0);
   return HSA_STATUS_SUCCESS;
   CATCH;
 }
